@@ -8,5 +8,5 @@ class BasePatch(BaseModel):
         return {
             field
             for field in self.__fields__
-            if field not in exclude and is_unset(getattr(self, field))
+            if field not in exclude and not is_unset(getattr(self, field))
         }
